==> bouml_2.7.4.tar.gz: bouml_2.7.4/genplugouts/html/cpp/UmlState.cpp <==

#include "UmlStateDiagram.h"
#include "UmlState.h"

QCString UmlState::sKind() {
  return (parent()->kind() == aClassView)
    ? "state machine" : "state";
}

void UmlState::html(QCString pfix, unsigned int) {
  define();

  if (parent()->kind() == aClassView)
    fw.write("<table bgcolor=\"#d3d3d3\"><td><font size=\"+1\">State Machine  <b>");
  else
    fw.write("<table bgcolor=\"#d3d3d3\"><td><font size=\"+1\">State  <b>");
  writeq(name());
  fw.write("</b></font><br></td></table>");

  fw.write("<p>Entry Behavior :<br><p><ul>");
  
  QCString s = entryBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>OCL : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = cppEntryBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>C++ : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = javaEntryBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>Java : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  fw.write("</ul>");

  fw.write("<p>Exit Behavior :<br><p><ul>");
  
  s = exitBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>OCL : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = cppExitBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>C++ : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = javaExitBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>Java : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  fw.write("</ul>");

  fw.write("<p>Do activity :<br><p><ul>");
  
  s = doActivity();

  if (!s.isEmpty()) {
    fw.write("<li>OCL : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = cppDoActivity();

  if (!s.isEmpty()) {
    fw.write("<li>C++ : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = javaDoActivity();

  if (!s.isEmpty()) {
    fw.write("<li>Java : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  fw.write("</ul>");
 
  s = description();
  
  if (!s.isEmpty()) {
    fw.write("<p>");
    writeq(description());
    fw.write("<br></p>");
  }

  UmlStateDiagram * d = associatedDiagram();
  
  if (d != 0) {
    fw.write("<p>Diagram : ");
    d->write();
    fw.write("</p>");
  }
  
  const QVector<UmlItem> ch = children();
  
  for (unsigned i = 0; i != ch.size(); i += 1)
    ch[i]->html(pfix, 0);

  unload(FALSE, FALSE);
}

==> bouml_2.15.4.tar.gz: bouml_2.15.4/genplugouts/html/cpp/UmlState.cpp <==

#include "UmlStateDiagram.h"
#include "UmlState.h"

QCString UmlState::sKind() {
  return (parent()->kind() == aClassView)
    ? "state machine" : "state";
}

void UmlState::html(QCString pfix, unsigned int rank, unsigned int level) {
  define();

  chapter((parent()->kind() == aClassView)
	  ? "StateMachine" : "State",
	  pfix, rank, "state", level);

  fw.write("<p>Entry Behavior :<br><p><ul>");
  
  QCString s = entryBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>OCL : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = cppEntryBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>C++ : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = javaEntryBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>Java : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  fw.write("</ul>");

  fw.write("<p>Exit Behavior :<br><p><ul>");
  
  s = exitBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>OCL : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = cppExitBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>C++ : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = javaExitBehavior();

  if (!s.isEmpty()) {
    fw.write("<li>Java : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  fw.write("</ul>");

  fw.write("<p>Do activity :<br><p><ul>");
  
  s = doActivity();

  if (!s.isEmpty()) {
    fw.write("<li>OCL : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = cppDoActivity();

  if (!s.isEmpty()) {
    fw.write("<li>C++ : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  s = javaDoActivity();

  if (!s.isEmpty()) {
    fw.write("<li>Java : <pre>\n");
    writeq(s);
    fw.write("</pre></li>");
  }

  fw.write("</ul>");
 
  s = description();
  
  if (!s.isEmpty()) {
    fw.write("<p>");
    writeq(description());
    fw.write("<br></p>");
  }

  UmlStateDiagram * d = associatedDiagram();
  
  if (d != 0) {
    fw.write("<p>Diagram : ");
    d->write();
    fw.write("</p>");
  }

  write_children(pfix, rank, level);

  unload(FALSE, FALSE);
}

void UmlState::memo_ref() {
  states.addElement(this);
  UmlItem::memo_ref();
}

void UmlState::ref_index()
{
  if (!states.isEmpty())
    fw.write("<a href=\"states.html\" target = \"projectFrame\"><b> -States- </b></a>");
}

void UmlState::generate_index()
{
  UmlItem::generate_index(states, "States", "states");
}

bool UmlState::chapterp() {
  return TRUE;
}

Vector UmlState::states;
